@@ -1,10 +1,10 @@
-from .helper import parse_rule_list, inherit_json, get_classpath_separator
+from .helper import parse_rule_list, inherit_json, get_classpath_separator, get_library_path
 from .runtime import get_executable_path
 from .exceptions import VersionNotFound
 from typing import Dict, List, Any, Union
 from .utils import get_library_version
+from .types import MinecraftOptions
 from .natives import get_natives
-import platform
 import json
 import copy
 import os
@@ -16,26 +16,18 @@ def get_libraries(data: Dict[str, Any], path: str) -> str:
     """
     Returns the argument with all libs that come after -cp
     """
-    if platform.system() == "Windows":
-        classpath_seperator = ";"
-    else:
-        classpath_seperator = ":"
+    classpath_seperator = get_classpath_separator()
     libstr = ""
     for i in data["libraries"]:
         if not parse_rule_list(i, "rules", {}):
             continue
-        current_path = os.path.join(path, "libraries")
-        lib_path, name, version = i["name"].split(":")
-        for lib_part in lib_path.split("."):
-            current_path = os.path.join(current_path, lib_part)
-        current_path = os.path.join(current_path, name, version)
+        libstr += get_library_path(i["name"], path) + classpath_seperator
         native = get_natives(i)
-        if native == "":
-            jar_filename = name + "-" + version + ".jar"
-        else:
-            jar_filename = name + "-" + version + "-" + native + ".jar"
-        current_path = os.path.join(current_path, jar_filename)
-        libstr = libstr + current_path + classpath_seperator
+        if native != "":
+            if "downloads" in i:
+                libstr += os.path.join(path, "libraries", i["downloads"]["classifiers"][native]["path"]) + classpath_seperator
+            else:
+                libstr += get_library_path(i["name"] + "-" + native, path) + classpath_seperator
     if "jar" in data:
         libstr = libstr + os.path.join(path, "versions", data["jar"], data["jar"] + ".jar")
     else:
@@ -43,7 +35,7 @@ def get_libraries(data: Dict[str, Any], path: str) -> str:
     return libstr
 
 
-def replace_arguments(argstr: str, versionData: Dict[str, Any], path: str, options: Dict[str, Any]) -> str:
+def replace_arguments(argstr: str, versionData: Dict[str, Any], path: str, options: MinecraftOptions) -> str:
     """
     Replace all placeholder in arguments with the needed value
     """
@@ -70,7 +62,7 @@ def replace_arguments(argstr: str, versionData: Dict[str, Any], path: str, optio
     return argstr
 
 
-def get_arguments_string(versionData: Dict[str, Any], path: str, options: Dict[str, Any]) -> List[str]:
+def get_arguments_string(versionData: Dict[str, Any], path: str, options: MinecraftOptions) -> List[str]:
     """
     Turns the argument string from the version.json into a list
     """
@@ -89,7 +81,7 @@ def get_arguments_string(versionData: Dict[str, Any], path: str, options: Dict[s
     return arglist
 
 
-def get_arguments(data: Dict[str, Any], versionData: Dict[str, Any], path: str, options: Dict[str, Any]) -> List[str]:
+def get_arguments(data: Dict[str, Any], versionData: Dict[str, Any], path: str, options: MinecraftOptions) -> List[str]:
     """
     Returns all arguments from the version.json
     """
@@ -115,7 +107,7 @@ def get_arguments(data: Dict[str, Any], versionData: Dict[str, Any], path: str,
     return arglist
 
 
-def get_minecraft_command(version: str, minecraft_directory: Union[str, os.PathLike], options: Dict[str, Any]) -> List[str]:
+def get_minecraft_command(version: str, minecraft_directory: Union[str, os.PathLike], options: MinecraftOptions) -> List[str]:
     """
     Returns a command for launching Minecraft. For more information take a look at the documentation.
     """
