@@ -1,11 +1,10 @@
-from .helper import download_file, get_library_path, get_jar_mainclass, get_user_agent, empty
+from .helper import download_file, get_library_path, get_jar_mainclass, parse_maven_metadata, empty
 from .install import install_minecraft_version, install_libraries
-from typing import NoReturn, Dict, List, Any, Callable, Union
+from typing import Dict, List, Any, Union, Optional
 from .exceptions import VersionNotFound
-from xml.dom import minidom
+from .types import CallbackDict
 import subprocess
 import platform
-import requests
 import tempfile
 import random
 import zipfile
@@ -16,7 +15,7 @@ import os
 __all__ = ["install_forge_version", "run_forge_installer", "list_forge_versions", "find_forge_version", "is_forge_version_valid", "supports_automatic_install"]
 
 
-def extract_file(handler: zipfile.ZipFile, zip_path: str, extract_path: str) -> NoReturn:
+def extract_file(handler: zipfile.ZipFile, zip_path: str, extract_path: str) -> None:
     """
     Extract a file from a zip handler into the given path
     """
@@ -47,7 +46,7 @@ def get_data_library_path(libname: str, path: str) -> str:
     return libpath
 
 
-def forge_processors(data: Dict[str, Any], minecraft_directory: Union[str, os.PathLike], lzma_path: str, installer_path: str, callback: Dict[str, Callable], java: str = None) -> NoReturn:
+def forge_processors(data: Dict[str, Any], minecraft_directory: Union[str, os.PathLike], lzma_path: str, installer_path: str, callback: CallbackDict, java: str = None) -> None:
     """
     Run the processors of the install_profile.json
     """
@@ -87,15 +86,15 @@ def forge_processors(data: Dict[str, Any], minecraft_directory: Union[str, os.Pa
             else:
                 command.append(var)
         for key, value in argument_vars.items():
-            for i in range(len(command)):
-                command[i] = command[i].replace(key, value)
+            for pos in range(len(command)):
+                command[pos] = command[pos].replace(key, value)
         subprocess.call(command)
         callback.get("setProgress", empty)(count)
     if os.path.exists(root_path):
         shutil.rmtree(root_path)
 
 
-def install_forge_version(versionid: str, path: str, callback: Dict[str, Callable] = None, java: str = None) -> NoReturn:
+def install_forge_version(versionid: str, path: str, callback: Optional[CallbackDict] = None, java: str = None) -> None:
     """
     Installs a forge version. Fore more information look at the documentation.
     """
@@ -142,7 +141,7 @@ def install_forge_version(versionid: str, path: str, callback: Dict[str, Callabl
         os.remove(lzma_path)
 
 
-def run_forge_installer(version: str, java: str = None) -> NoReturn:
+def run_forge_installer(version: str, java: str = None) -> None:
     """
     Run the forge installer of the given forge version
     """
@@ -158,15 +157,10 @@ def list_forge_versions() -> List[str]:
     Returns a list of all forge versions
     """
     MAVEN_METADATA_URL = "https://files.minecraftforge.net/maven/net/minecraftforge/forge/maven-metadata.xml"
-    r = requests.get(MAVEN_METADATA_URL, headers={"user-agent": get_user_agent()}).text
-    xml_data = minidom.parseString(r)
-    version_list = []
-    for i in xml_data.getElementsByTagName("version"):
-        version_list.append(i.childNodes[0].wholeText)
-    return version_list
+    return parse_maven_metadata(MAVEN_METADATA_URL)["versions"]
 
 
-def find_forge_version(vanilla_version: str) -> str:
+def find_forge_version(vanilla_version: str) -> Optional[str]:
     """
     Find the latest forge version that is compatible to the given vanilla version
     """
@@ -200,3 +194,15 @@ def supports_automatic_install(forge_version: str) -> bool:
             return False
     except Exception:
         return False
+
+
+def forge_to_installed_version(forge_version: str) -> str:
+    """
+    Returns the Version under which Forge will be installed from the given Forge version.
+    Raises a ValueError if the Version is invalid.
+    """
+    try:
+        vanilla_part, forge_part = forge_version.split("-")
+        return f"{vanilla_part}-forge-{forge_part}"
+    except ValueError:
+        raise ValueError(f"{forge_version} is not a valid forge version") from None
